powered by
The procedure control if the correlation model is bivariate.
CheckBiv(numbermodel)
Return TRUE or FALSE depending if the correlation model is bivariate or not.
numeric; the number associated to a given correlation model.
Moreno Bevilacqua, [email protected],https://sites.google.com/view/moreno-bevilacqua/home, Víctor Morales Oñate, [email protected], https://sites.google.com/site/moralesonatevictor/, Christian", Caamaño-Carrillo, [email protected],https://www.researchgate.net/profile/Christian-Caamano
The function check if the correlation model is bivariate.
library(GeoModels) CheckBiv(CkCorrModel("Bi_matern_sep"))
Run the code above in your browser using DataLab