Subroutine called by InitParam.\
The procedure controls the type of random field inserted by the users.
CkModel(model)The function returns a numeric positive integer, or NULL if the model is invalid.
String; the density associated with the likelihood
objects. Gaussian is the default.
Moreno Bevilacqua [email protected] https://sites.google.com/view/moreno-bevilacqua/home \ Víctor Morales Oñate [email protected] https://sites.google.com/site/moralesonatevictor/ \ Christian Caamaño-Carrillo [email protected] https://www.researchgate.net/profile/Christian-Caamano
The function controls the type of random field inserted by the users.
GeoFit