Learn R Programming

GeoModels (version 2.2.8)

CkType: Checking Likelihood Objects

Description

Subroutine called by InitParam. \ The procedure controls the type of likelihood objects inserted by the users.

Usage

CkType(type)

Value

The function returns a numeric positive integer, or NULL if the type of likelihood is invalid.

Arguments

type

String; the type of likelihood object. Supported values are Pairwise, Standard, Tapering, Tapering1, Tapering2, GeoWLS, CV, and Independence.

Details

The procedure checks the likelihood object.

See Also

GeoFit