Learn R Programming

GeoModels (version 2.2.5)

CorrParam: Lists the Parameters of a Correlation Model

Description

The procedure returns a list with the names of the parameters of a given correlation model.

Usage

CorrParam(corrmodel)

Value

Return a vector string of correlation parameters.

Arguments

corrmodel

String: the name associated to a given correlation model.

Details

The function returns a list with the Parameters of a Correlation Model

See Also

GeoCovmatrix

Examples

Run this code
require(GeoModels)
################################################################
###
### Example 1. Parameters of the Matern model
###
###############################################################

CorrParam("Matern")


################################################################
###
### Example 2. Parameters of the Generalized Wendland model
###
###############################################################

CorrParam("GenWend")


################################################################
###
### Example 3. Parameters of the Generalized Cauchy model
###
###############################################################

CorrParam("GenCauchy")


################################################################
###
### Example 4. Parameters of the space time Gneiting model
###
###############################################################

CorrParam("Gneiting")


################################################################
###
### Example 5. Parameters of the bi-Matern separable model.
### Note that in the bivariate case variance paramters are
### included
###############################################################

CorrParam("Bi_Matern_sep")

Run the code above in your browser using DataLab