GeoNA: Deleting NA values (missing values) from a spatial or...

View source: R/GeoNA.R

GeoNAR Documentation

Deleting NA values (missing values) from a spatial or spatio-temporal dataset.

Description

The function deletes NA values from a spatial or spatio-temporal dataset

Usage

GeoNA(data, coordx = NULL, coordy=NULL,coordz=NULL, coordt=NULL,
coordx_dyn=NULL, grid=FALSE, X=NULL, setting="spatial")

Arguments

data

A d-dimensional vector (a single spatial realisation) or a (d \times d)-matrix (a single spatial realisation on regular grid) or a (t \times d)-matrix (a single spatio-temporal realisation) or an (d \times d \times t \times n )-array (a single spatio-temporal realisation on regular grid) giving the data.

coordx

A numeric (d \times 2)-matrix or (d \times 3)-matrix Coordinates on a sphere for a fixed radius radius are passed in lon/lat format expressed in decimal degrees.

coordy

A numeric vector giving 1-dimension of spatial coordinates; Optional argument, the default is NULL.

coordz

A numeric vector giving 1-dimension of spatial coordinates; Optional argument, the default is NULL.

coordt

A numeric vector giving one dimension of temporal coordinates; the default is NULL, in which case a spatial random field is expected. Temporal coordinates may be irregularly spaced and their supplied numeric values are preserved.

coordx_dyn

For dynamic locations, a list with one two- or three-column coordinate matrix per time. It must be aligned with the list data; missing responses remove the corresponding rows from both objects.

grid

Logical; if FALSE (the default) the data are interpreted as spatial or spatio-temporal realisations on a set of non-equispaced spatial sites (irregular grid).

X

Covariates aligned with data. For fixed-coordinate space-time data, use an TN \times p matrix ordered as c(t(data)). For dynamic data, X must be a list with X[[t]] having one row per element of data[[t]] and per row of coordx_dyn[[t]].

setting

String; are data spatial, spatio-temporal or spatial bivariate (respectively spatial, spacetime, bivariate)

Value

Returns a list containing the following components:

coordx

A d-dimensional vector of spatial coordinates;

coordy

A d-dimensional vector of spatial coordinates;

coordt

A t-dimensional vector of temporal coordinates;

data

The data without NAvalues

grid

TRUE if the spatial data are observed in a regular grid, otherwise FALSE;

perc

The percentage of NA values.

setting

Are data of spatial or spatio-temporal or spatial bivariate type

X

The covariate matrix after deleting the rows corresponding to removed observations. For fixed-coordinate spatio-temporal data, deleting a site removes its row from every temporal block.

Spatio-temporal ordering

For fixed sites, data has times in rows and sites in columns; rows of X follow time-major order. Removing a site removes the corresponding column of data, coordinate row, and its row from every temporal block of X. For dynamic sites, data, coordx_dyn, and X are aligned lists and missing values are removed independently within each temporal block. See GeoModels-spacetime-ordering.

Author(s)

Moreno Bevilacqua, moreno.bevilacqua89@gmail.com,https://sites.google.com/view/moreno-bevilacqua/home, Víctor Morales Oñate, victor.morales@uv.cl, https://sites.google.com/site/moralesonatevictor/, Christian Caamaño-Carrillo, chcaaman@ubiobio.cl,https://www.researchgate.net/profile/Christian-Caamano

Examples


library(GeoModels)

# Define the spatial-coordinates of the points:
set.seed(79)
x = runif(200, 0, 1)
y = runif(200, 0, 1)
coords=cbind(x,y)
# Set the exponential cov parameters:
corrmodel = "Matern"
mean=0
sill=1
nugget=0
scale=0.3/3
smooth=0.5
param=list(mean=mean,sill=sill,nugget=nugget,scale=scale,smooth=smooth)

# Simulation of the spatial Gaussian random field:
data = GeoSim(coordx=coords, corrmodel=corrmodel,
 param=param)$data


data[1:100]=NA
# removing NA
a=GeoNA(data,coordx=coords)
a$perc # percentage of NA values 
#a$coordx# spatial coordinates without missing values
#a$data # data without missinng values



GeoModels documentation built on Sept. 23, 2026, 5:07 p.m.

Related to GeoNA in GeoModels...