| MargParam | R Documentation |
The procedure returns a list with the nuisance parameters of a given random field model.
MargParam(model, bivariate=FALSE,num_betas=c(1,1),copula=NULL)
model |
String; the name of a random field. |
bivariate |
Logical; if |
num_betas |
Numerical; the nunber of mean parameters in the linear specification (default is 1) |
copula |
The type of copula. |
The function returns a list with the nuisance parameters of a given random field model.
Return a vector string of nuisance parameters.
Moreno Bevilacqua, moreno.bevilacqua89@gmail.com,https://sites.google.com/view/moreno-bevilacqua/home, Víctor Morales Oñate, victor.morales@uv.cl, https://sites.google.com/site/moralesonatevictor/, Christian", Caamaño-Carrillo, chcaaman@ubiobio.cl,https://www.researchgate.net/profile/Christian-Caamano
GeoFit
library(GeoModels)
MargParam("Gaussian")
MargParam("Binomial")
MargParam("Weibull",num_betas=2)
MargParam("SkewGaussian", num_betas=3)
MargParam("SinhAsinh")
MargParam("Beta2",copula="Clayton")
MargParam("StudentT")
## note that in the bivariate case sill_1 e sill_2 are considered as correlation parameteres
MargParam("Gaussian", bivariate=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.