| StartParam | R Documentation |
Subroutine called by the fitting procedures. The procedure initializes the parameters for the fitting procedure.
StartParam(coordx, coordy, coordz, coordt, coordx_dyn, corrmodel,
data, distance, fcall, fixed, grid, likelihood,
maxdist, neighb, maxtime, model, n, param,
parscale, paramrange, radius, start, taper, tapsep,
type, typereal, weighted, copula, X, memdist, nosym,
p_neighb, thin_method)
coordx |
A numeric ( |
coordy |
A numeric vector giving 1-dimension of spatial coordinates; optional argument, default is |
coordz |
A numeric vector giving 1-dimension of spatial coordinates; optional argument, default is |
coordt |
A numeric vector assigning 1-dimension of temporal coordinates. |
coordx_dyn |
A list of |
corrmodel |
String; the name of a correlation model. |
data |
A numeric vector or a ( |
distance |
String; the name of the spatial distance. Default is |
fcall |
String; |
fixed |
A named list giving the values of the parameters that will be considered as known values. |
grid |
Logical; if |
likelihood |
String; the configuration of the composite likelihood. |
maxdist |
Numeric; an optional positive value indicating the maximum spatial distance considered in the composite-likelihood computation. |
neighb |
Numeric; an optional positive integer indicating the order of neighborhood in the composite likelihood computation. See the Section Details for more information. |
maxtime |
Numeric; an optional positive value indicating the maximum temporal lag considered in the composite-likelihood computation. |
model |
String; the density associated to the likelihood objects. |
n |
Numeric; number of trials for binomial random fields. |
param |
A numeric vector of parameter values required in the simulation procedure of random fields. |
parscale |
A numeric vector of scaling factors to improve the maximizing procedure; see |
paramrange |
A numeric vector of parameter ranges; see |
radius |
Numeric; the radius of the sphere in the case of lon-lat coordinates.
The default is |
start |
A named list with the initial values of the parameters that are used by the numerical routines in the maximization procedure. |
taper |
String; the name of the type of covariance matrix. It can be |
tapsep |
Numeric; an optional value indicating the separability parameter in the space-time adaptive taper (see Details). |
type |
String; the type of likelihood objects. Temporary value set to |
typereal |
String; the real type of likelihood objects. See |
weighted |
Logical; if |
copula |
String; the type of copula. |
X |
Numeric; matrix of space-time covariates. |
memdist |
Logical; if |
nosym |
Logical; if |
p_neighb |
Numeric; a value in |
thin_method |
String; thinning scheme used when |
Internal function called by WlsStart.
A list with a set of useful information in the estimation procedure.
Moreno Bevilacqua, moreno.bevilacqua89@gmail.com, https://sites.google.com/view/moreno-bevilacqua/home, Víctor Morales Oñate, victor.morales@uv.cl, https://sites.google.com/site/moralesonatevictor/, Christian Caamaño-Carrillo, chcaaman@ubiobio.cl, https://www.researchgate.net/profile/Christian-Caamano
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.