WlsStart: Computes Starting Values based on Weighted Least Squares

View source: R/GeoWls.r

WlsStartR Documentation

Computes Starting Values based on Weighted Least Squares

Description

Subroutine called by GeoFit. The function returns appropriate starting values for the composite-likelihood fitting procedure based on weighted least squares.

Usage

WlsStart(coordx, coordy, coordz, coordt, coordx_dyn, corrmodel, data,
         distance, fcall, fixed, grid, likelihood, maxdist, neighb,
         maxtime, model, n, param, parscale, paramrange, radius, start,
         taper, tapsep, type, varest, weighted, copula, X, memdist,
         nosym, p_neighb, thin_method)

Arguments

coordx

A numeric (d \times 2)-matrix or (d \times 3)-matrix. Coordinates on a sphere for a fixed radius radius are passed in lon/lat format expressed in decimal degrees.

coordy

A numeric vector giving 1-dimension of spatial coordinates; optional argument, default is NULL.

coordz

A numeric vector giving 1-dimension of spatial coordinates; optional argument, default is NULL.

coordt

A numeric vector assigning 1-dimension of temporal coordinates.

coordx_dyn

A list of m numeric (d_t \times 2)-matrices containing dynamical (in time) spatial coordinates. Optional argument, default is NULL.

corrmodel

String; the name of a correlation model.

data

A numeric vector or a (n \times d)-matrix or (d \times d \times n)-array of observations.

distance

String; the name of the spatial distance. Default is "Eucl" (euclidean distance).

fcall

String; "fitting" to call the fitting procedure and "simulation" to call the simulation procedure.

fixed

A named list giving the values of the parameters that will be considered as known values.

grid

Logical; if FALSE (default) the data are interpreted as a vector or a (n \times d)-matrix; if TRUE then a (d \times d \times n)-array is considered.

likelihood

String; the configuration of the composite likelihood.

maxdist

Numeric; an optional positive value indicating the maximum spatial distance considered in the composite-likelihood computation.

neighb

Numeric; an optional positive integer indicating the order of neighborhood in the composite likelihood computation.

maxtime

Numeric; an optional positive value indicating the maximum temporal separation considered in the composite-likelihood computation.

model

String; the name of the model.

n

Numeric; number of trials in a binomial random field.

param

A numeric vector of parameter values required in the simulation procedure of random fields.

parscale

A numeric vector with scaling values for improving the maximisation routine.

paramrange

A numeric vector with the range of the parameter space.

radius

Numeric; a value indicating the radius of the sphere when using great circle distance. Default value is the radius of the earth in km (i.e., 6371).

start

A numeric vector (or list) with starting values.

taper

String; the name of the type of covariance matrix. It can be "Standard" (default) or "Tapering" for tapered covariance matrices.

tapsep

Numeric; an optional value indicating the separability parameter in the space-time quasi taper (see Details).

type

String; the type of estimation method.

varest

Logical; if TRUE the estimates variances and standard errors are returned. Default is FALSE.

weighted

Logical; if TRUE the likelihood objects are weighted; see GeoFit.

copula

String; the type of copula. It can be "Clayton" or "Gaussian".

X

Numeric; matrix of spatio(temporal) covariates in the linear mean specification.

memdist

Logical; if TRUE then the distances in the composite likelihood are computed before the optimization.

nosym

Logical; if TRUE symmetric weights are not considered.

p_neighb

Numeric; a value in (0,1] specifying the expected fraction of nearest-neighbor pairs retained through stochastic thinning. If 1 (default), no thinning is applied and all nearest-neighbor pairs are used. If <1, pairs are randomly retained using independent Bernoulli sampling.

thin_method

String; thinning scheme used when p_neighb<1. Default is "iid" (independent Bernoulli thinning).

Details

Internal function called by GeoFit.

Value

A list with a set of useful information in the estimation procedure.

Author(s)

Moreno Bevilacqua, moreno.bevilacqua89@gmail.com, https://sites.google.com/view/moreno-bevilacqua/home, Víctor Morales Oñate, victor.morales@uv.cl, https://sites.google.com/site/moralesonatevictor/, Christian Caamaño-Carrillo, chcaaman@ubiobio.cl, https://www.researchgate.net/profile/Christian-Caamano

See Also

GeoFit.


GeoModels documentation built on April 6, 2026, 5:08 p.m.