plot.GeoVariogram: Plot empirical spatial, spatio-temporal and bivariate...

View source: R/GeoVariogram.r

plot.GeoVariogramR Documentation

Plot empirical spatial, spatio-temporal and bivariate semivariograms

Description

Plot an empirical spatial, spatio-temporal, or bivariate semivariogram returned by GeoVariogram.

Usage

## S3 method for class 'GeoVariogram'
plot(x, ...)

Arguments

x

an object of the class "GeoVariogram"

...

other arguments to be passed to the function plot

Details

Spatial objects are shown as a standard lag plot. Spatio-temporal objects show the empirical surface and its spatial and temporal margins. Bivariate objects show the two marginal semivariograms and the cross-semivariogram; missing empirical bins are handled as NA.

Value

Produces a plot. No values are returned.

See Also

GeoVariogram for variogram computation and examples.


GeoModels documentation built on Sept. 23, 2026, 5:07 p.m.