- data
A \(d\)-dimensional vector (a single spatial realisation) or a (\(d \times d\))-matrix (a single spatial realisation on
regular grid)
or a
(\(t \times d\))-matrix (a single spatio-temporal realisation) or an (\(d \times d \times t \times n \))-array
(a single spatio-temporal realisation on regular grid).
See Details for the accepted data layouts.
- coordx
A numeric (\(d \times 2\))-matrix or (\(d \times 3\))-matrix
Coordinates on a sphere for a fixed radius radius
are passed in lon/lat format expressed in decimal degrees.
- coordy
A numeric vector giving 1-dimension of
spatial coordinates; Optional argument, the default is NULL.
- coordz
A numeric vector giving 1-dimension of
spatial coordinates; Optional argument, the default is NULL.
- coordt
A numeric vector assigning 1-dimension of
temporal coordinates. Optional argument, the default is NULL
then a spatial random fields is expected.
- coordx_dyn
A list of \(m\) numeric (\(d_t \times 2\))-matrices
containing dynamical (in time) spatial coordinates. Optional argument, the default is NULL
- copula
String; the type of copula. It can be "Clayton" or "Gaussian"
- corrmodel
String; the name of a correlation model, for the
see GeoCovmatrix for the list of implemented correlation models.
- distance
String; the name of the spatial distance. The default is Eucl, the Euclidean distance.
See Details for the accepted options.
- fixed
An optional named list giving the values of the parameters that
will be considered as known values. The listed parameters for a
given correlation function will be not estimated.
- anisopars
A list of two elements: "angle" and "ratio" i.e. the anisotropy angle and the anisotropy ratio, respectively.
- est.aniso
A bivariate logical vector providing which anisotropic parameters must be estimated.
- grid
Logical; if FALSE (the default) the data
are interpreted as spatial or spatio-temporal realisations on a set
of non-equispaced spatial sites (irregular grid).
- likelihood
String; the configuration of the composite
likelihood. Marginal is the default (see GeoFit for details).
- lower
An optional named list giving the values for the lower bound of the space parameter
when the optimizer is L-BFGS-B or nlminb or bobyqa or optimize. The
names of the list must be the same of the names in the start list.
- neighb
Numeric; a vector of positive integers indicating the
order of neighborhood in the weight function of composite likelihood
(see GeoFit for details).
- p_neighb
Numeric; a value in \((0,1]\) that specifies the expected fraction
of nearest-neighbor pairs retained through stochastic thinning.
If is equal to 1 (default), no thinning is applied and all nearest-neighbor
pairs are used. If it is lower than 1, nearest-neighbor pairs are randomly retained using
independent Bernoulli sampling.
- maxtime
Numeric; an optional positive integer indicating the
order of temporal neighborhood in the composite likelihood
computation.
- memdist
Logical; if TRUE then all the distances useful in the composite likelihood
estimation are computed before the optimization. FALSE is deprecated.
- model
String; the type of random fields and therefore the densities associated to the likelihood
objects. Gaussian is the default, see GeoFit for details.
- n
Numeric; number of trials in a binomial random fields; number of successes in a negative binomial random fields
- ncores
Numeric; the number of cores involved in the parallelization
- optimizer
String; the optimization algorithm
(see optim for details). Nelder-Mead is the
default. Other possible choices are nlm, BFGS, SANN, L-BFGS-B and nlminb and
bobyqa.
In these last three cases upper and lower bounds can be passed by the user. In the case
of one-dimensional optimization, the function optimize is used.
- parallel
Logical; if TRUE the procedure is parallelized using dofuture.
- bivariate
Logical; if TRUE the bivariate case is considered.
- radius
Numeric; the radius of the sphere in the case of lon-lat coordinates.
Default value is 1.
- start
An optional named list with the initial values of the
parameters that are used by the numerical routines in maximization
procedure. NULL is the default (see GeoFit for details).
- type
String; the type of the likelihood objects. If Pairwise (the
default) then the marginal composite likelihood is formed by
pairwise marginal likelihoods (see GeoFit for details).
- upper
An optional named list giving the values for the upper bound
of the space parameter when the optimizer is or L-BFGS-B or bobyqa or nlminb or optimize.
The names of the list must be the same of the names in the start list.
- weighted
Logical; if TRUE the likelihood objects are
weighted (see GeoFit for details). If FALSE (the
default) the composite likelihood is not weighted.
- X
Numeric; Matrix of spatio(temporal)covariates in the linear mean specification.
- spobj
An object of class sp or spacetime
- spdata
Character:The name of data in the sp or spacetime object
- vario
An object of the class GeoVariogram obtained using the GeoVariogram function
- progress
Logic; If TRUE then a progress bar is shown.