Given a set of spatio (temporal) locations and data, the procedure select the spatial or spatiotemporal ouliers using a specific algorithm.
GeoOutlier(data, coordx, coordy=NULL,coordz=NULL, coordt=NULL, coordx_dyn=NULL,
distance="Eucl", grid=FALSE, neighb=10,alpha=0.001,
method="Z-Median", radius=1, bivariate=FALSE,X=NULL)Return a matrix or a list containing the dected spatial or spatio-temporal outliers
An optional \(d\)-dimensional vector (a single spatial realisation) or a (\(d \times d\))-matrix (a single spatial realisation on regular grid) or a (\(t \times d\))-matrix (a single spatio-temporal realisation) or an (\(d \times d \times t \times n \))-array (a single spatio-temporal realisation on regular grid).
A numeric (\(d \times 2\))-matrix or (\(d \times 3\))-matrix
Coordinates on a sphere for a fixed radius radius
are passed in lon/lat format expressed in decimal degrees.
A numeric vector giving 1-dimension of
spatial coordinates; Optional argument, the default is NULL.
A numeric vector giving 1-dimension of
spatial coordinates; Optional argument, the default is NULL.
A numeric vector giving 1-dimension of
temporal coordinates. Optional argument, the default is NULL
then a spatial RF is expected.
A list of \(m\) numeric (\(d_t \times 2\))-matrices
containing dynamical (in time) spatial coordinates. Optional argument, the default is NULL
String; the name of the spatial distance. The default
is Eucl, the Euclidean distance. See GeoFit for details.
Logical; if FALSE (the default) the data
are interpreted as spatial or spatio-temporal realisations on a set
of non-equispaced spatial sites (irregular grid).
Numeric; an optional positive integer indicating the order of neighborhoodused for Z-Median algorithm.
Numeric; a numeric value between 0 and 1 used for Z-Median algorithm.
String; The name of the algorithm for detecting spatial ouliers. Default is Z-median proposed in Chen et al. (2008)
Numeric; a value indicating the radius of the sphere when using the great circle distance. Default value is 1.
If TRUE then data is considered as spatial bivariate data.
Numeric; an optional Matrix of spatio (temporal) covariates.
Moreno Bevilacqua, moreno.bevilacqua89@gmail.com,https://sites.google.com/view/moreno-bevilacqua/home, Víctor Morales Oñate, victor.morales@uv.cl, https://sites.google.com/site/moralesonatevictor/, Christian Caamaño-Carrillo, chcaaman@ubiobio.cl,https://www.researchgate.net/profile/Christian-Caamano
Chen D, Lu C, Kou Y, Chen F (2008) On detecting spatial outliers. Geoinformatica 12:455–475
Bevilacqua M., Caamaño C., Arellano-Valle R. B., Camilo Gomez C. (2022) A class of random fields with two-piece marginal distributions for modeling point-referenced data with spatial outliers. Test 10.1007/s11749-021-00797-5