- data
A \(d\)-dimensional vector (a single spatial realisation) or a (\(d \times d\))-matrix (a single spatial realisation on regular grid) or a
(\(t \times d\))-matrix (a single spatio-temporal realisation) or an (\(d \times d \times t \times n \))-array
(a single spatio-temporal realisation on regular grid). See GeoFit for details.
- coordx
A numeric (\(d \times 2\))-matrix or (\(d \times 3\))-matrix
Coordinates on a sphere for a fixed radius radius
are passed in lon/lat format expressed in decimal degrees.
- coordy
A numeric vector giving 1-dimension of
spatial coordinates; Optional argument, the default is NULL.
- coordz
A numeric vector giving 1-dimension of
spatial coordinates; Optional argument, the default is NULL.
- coordt
A numeric vector assigning 1-dimension of
temporal coordinates. Optional argument, the default is NULL then a spatial random field is expected.
- coordx_dyn
A list of \(m\) numeric (\(d_t \times 2\))-matrices
containing dynamical (in time) spatial coordinates. Optional argument, the default is NULL
- distance
String; the name of the spatial distance. The default
is Eucl, the Euclidean distance. See GeoFit for details.
- grid
Logical; if FALSE (the default) the data
are interpreted as spatial or spatio-temporal realisations on a set of
non-equispaced spatial sites.
- maxdist
A numeric value denoting the spatial maximum distance,
see Details for the accepted options.
- neighb
Numeric; an optional positive integer indicating the
order of neighborhood. See Details for more information.
- times
A numeric vector denoting the temporal instants involved Details.
- numbins
A numeric value denoting the numbers of bins, see the
Details.
- radius
Numeric; a value indicating the radius of the sphere when
using the great circle distance. Default value is 1.
- bivariate
Logical; if FALSE (the default) the data
are interpreted as univariate spatial or spatio-temporal realisations.
Otherwise they are intrepreted as a a realization from a bivariate field.
- ...
Optional parameters passed to the plot function.