| SimCE | R Documentation |
Internal subroutine used by GeoSimapprox to simulate a Gaussian
random field on an exact, regular two-dimensional grid by circulant
embedding.
SimCE(M, N, x, y, z = NULL, corrmodel, param,
mean.val = 0, max.ext = 1L)
M |
Integer; number of coordinates in |
N |
Integer; number of coordinates in |
x |
A finite, strictly increasing, equally spaced numeric vector of length |
y |
A finite, strictly increasing, equally spaced numeric vector of length |
z |
Must be |
corrmodel |
String; the name of a spatial correlation model. |
param |
A list of correlation parameters. |
mean.val |
A finite scalar or a vector with one value per grid point. |
max.ext |
Positive integer; maximum number of successive doubling attempts for the embedding. |
The simulated coordinates are exactly expand.grid(x, y). The method
uses Euclidean distance. If the embedding still has substantial negative
eigenvalues at the maximum extension, they are truncated to zero and a
warning is issued.
A list containing X, the simulated values, grid.points, the
exact grid coordinates, k0, the selected extension attempt,
approx.flag, and the minimum embedding eigenvalue.
Moreno Bevilacqua, moreno.bevilacqua89@gmail.com, Víctor Morales Oñate, victor.morales@uv.cl, Christian Caamaño-Carrillo, chcaaman@ubiobio.cl
GeoSimapprox
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.