| WlsStart | R Documentation |
Subroutine called by GeoFit.
The function returns appropriate starting values for the
composite-likelihood fitting procedure based on weighted least squares.
WlsStart(coordx, coordy, coordz, coordt, coordx_dyn, corrmodel, data,
distance, fcall, fixed, grid, likelihood, maxdist, neighb,
maxtime, model, n, param, parscale, paramrange, radius, start,
taper, tapsep, type, varest, weighted, copula, X, memdist,
nosym, p_neighb, thin_method)
coordx |
A numeric ( |
coordy |
A numeric vector giving 1-dimension of spatial coordinates; optional argument, default is |
coordz |
A numeric vector giving 1-dimension of spatial coordinates; optional argument, default is |
coordt |
A numeric vector assigning 1-dimension of temporal coordinates. |
coordx_dyn |
A list of |
corrmodel |
String; the name of a correlation model. |
data |
A numeric vector or a ( |
distance |
String; the name of the spatial distance. Default is |
fcall |
String; |
fixed |
A named list giving the values of the parameters that will be considered as known values. |
grid |
Logical; if |
likelihood |
String; the configuration of the composite likelihood. |
maxdist |
Numeric; an optional positive value indicating the maximum spatial distance considered in the composite-likelihood computation. |
neighb |
Numeric; an optional positive integer indicating the order of neighborhood in the composite likelihood computation. |
maxtime |
Numeric; an optional positive value indicating the maximum temporal separation considered in the composite-likelihood computation. |
model |
String; the name of the model. |
n |
Numeric; number of trials in a binomial random field. |
param |
A numeric vector of parameter values required in the simulation procedure of random fields. |
parscale |
A numeric vector with scaling values for improving the maximisation routine. |
paramrange |
A numeric vector with the range of the parameter space. |
radius |
Numeric; a value indicating the radius of the sphere when using great circle distance.
Default value is the radius of the earth in km (i.e., |
start |
A numeric vector (or list) with starting values. |
taper |
String; the name of the type of covariance matrix. It can be |
tapsep |
Numeric; an optional value indicating the separability parameter in the space-time quasi taper (see Details). |
type |
String; the type of estimation method. |
varest |
Logical; if |
weighted |
Logical; if |
copula |
String; the type of copula. It can be |
X |
Numeric; matrix of spatio(temporal) covariates in the linear mean specification. |
memdist |
Logical; if |
nosym |
Logical; if |
p_neighb |
Numeric; a value in |
thin_method |
String; thinning scheme used when |
Internal function called by GeoFit.
A list with a set of useful information in the estimation procedure.
Moreno Bevilacqua, moreno.bevilacqua89@gmail.com, https://sites.google.com/view/moreno-bevilacqua/home, Víctor Morales Oñate, victor.morales@uv.cl, https://sites.google.com/site/moralesonatevictor/, Christian Caamaño-Carrillo, chcaaman@ubiobio.cl, https://www.researchgate.net/profile/Christian-Caamano
GeoFit.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.