| plot.GeoVariogram | R Documentation |
Plot an empirical spatial, spatio-temporal, or bivariate semivariogram
returned by GeoVariogram.
## S3 method for class 'GeoVariogram'
plot(x, ...)
x |
an object of the class |
... |
other arguments to be passed to the function
|
Spatial objects are shown as a standard lag plot. Spatio-temporal objects
show the empirical surface and its spatial and temporal margins. Bivariate
objects show the two marginal semivariograms and the cross-semivariogram;
missing empirical bins are handled as NA.
Produces a plot. No values are returned.
GeoVariogram for variogram computation and examples.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.